package com.japontelucena.demos;

import android.app.Activity;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.os.IBinder;
import android.os.Messenger;
import android.os.RemoteException;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;
import com.japontelucena.services.WeatherInterface;

public class ServiceConsumerActivity extends Activity {

	Messenger messengerToService = null;
	public static TextView text_Weather;
	Button button_Bind;
	Button button_Query;
	Button button_Unbind;
	Button button_Exit;
	EditText edit_Location;

	ServiceConnection connection =	new JoseServiceAIDLConnection();
	SharedPreferences prefs;
	boolean isBound = false;
	WeatherInterface weather_reporter;

	void bind() {
		Intent intent = new Intent();
		intent.setAction("com.allmycode.WEATHER");
		isBound =
				bindService(intent, connection,
						Context.BIND_AUTO_CREATE);
	} 

	public void queryService() {

		String str_Weather_Report;
		if (isBound) {
			try {

				str_Weather_Report = weather_reporter.fetch_Weather(edit_Location.getText().toString());
				text_Weather.setText(str_Weather_Report);
			} catch (RemoteException e) {
				e.printStackTrace();
			}
		} else {
			text_Weather.setText(R.string.service_not_bound);
		}      
	}

	void unbind() {
		if (isBound) {
			unbindService(connection);
			isBound = false;
		}
	}

	class JoseServiceAIDLConnection implements ServiceConnection {
		public void onServiceConnected(
				ComponentName component_Class_Name, IBinder bind_Weather) {
			weather_reporter = WeatherInterface.Stub.asInterface(bind_Weather);
			show_Toast(R.string.service_connected);      
		}

		public void onServiceDisconnected(ComponentName component_Name) {
			show_Toast(R.string.service_crashed);
		}
	}

	void show_Toast(int resource_Weather) {
		Toast.makeText(this, resource_Weather, Toast.LENGTH_SHORT).show();
	}

	@Override
	public void onDestroy() { 
		super.onDestroy();
		prefs = getSharedPreferences("PREFS", MODE_PRIVATE);
		SharedPreferences.Editor editor = prefs.edit();
		editor.putBoolean("isBound", isBound);
		editor.putString("report", text_Weather.getText().toString());
		editor.commit();

		unbind();
	}

	@Override
	public void onCreate(Bundle bundle_Instance_State) {
		
		ButtonListener listen_Button = new ButtonListener();
		
		super.onCreate(bundle_Instance_State);
		setContentView(R.layout.main);
		prefs = getSharedPreferences("PREFS", MODE_PRIVATE);
		if (prefs != null) {
			text_Weather = (TextView) findViewById(R.id.text_Weather);

			text_Weather.setText(prefs.getString("report",	getString(R.string.report_appears_here)));
			if (prefs.getBoolean("isBound", false)) {
				bind();
			}
		}

		button_Bind = (Button) findViewById(R.id.button_Bind);
		button_Bind.setOnClickListener(listen_Button);
		edit_Location =	(EditText) findViewById(R.id.edit_Location);
		button_Query = (Button) findViewById(R.id.button_Query);
		button_Query.setOnClickListener(listen_Button);
		button_Unbind =	(Button) findViewById(R.id.button_Unbind);
		button_Unbind.setOnClickListener(listen_Button);

		button_Exit = (Button) findViewById(R.id.button_Exit);
		button_Exit.setOnClickListener(listen_Button);
	}

	class ButtonListener implements OnClickListener {
		
		@Override
		public void onClick(View view_Button) {
			if (view_Button == button_Bind) 
				bind();
			else if (view_Button == button_Query) 
				queryService();
			else if (view_Button == button_Unbind) 
				unbind();
			else if (view_Button == button_Exit) 
				System.exit(0);
		}
	}
}
